| gutsPnL | R Documentation |
This is a volatility strategy consisting of a long position in an ITM (in the money call : ST is greater than call strike price of X1LC ) call option with a strike price X1LC, and a long position in an ITM (in the money put : ST is less than put strike of X2HP) put option with a strike price X2HP. This is a net debit trade. Since both call and put options are ITM, this strategy is more costly to establish than a long straddle position. The trader or investor has neutral outlook. This is a capital gain strategy (Kakushadze & Serur, 2018).
gutsPnL( ST, X2HP, X1LC, P, C, hl = 0, hu = 2, spot = spot, pl = pl, myData = myData, myTibble = myTibble, PnL = PnL )
ST |
Spot Price at time T. |
X2HP |
Higher Strike Price or eXercise price bought Put. |
X1LC |
Lower Strike Price or eXercise price bought Call. |
P |
Put Premium or Put Price paid for the bought put. |
C |
Call Premium or Call Price paid for the bought Call. |
hl |
lower bound value for setting lower-limit of x-axis displaying spot price. |
hu |
upper bound value for setting upper-limit of x-axis displaying spot price. |
spot |
Spot Price |
pl |
Profit and Loss |
myData |
Data frame |
myTibble |
tibble |
PnL |
Profit and Loss |
According to conceptual details given by Cohen (2015), and a closed form solution provided by Kakushadze and Serur (2018), this method is developed, and the given examples are created, to compute per share Profit and Loss at expiration for Guts Option Strategy and draw its graph in the Plots tab.
graph of the strategy
gutsPnL(25,27,24.75,2.5,3) gutsPnL(46,48,44,2,4,hl=0.6,hu=1.6) gutsPnL(1020,1025,1015,10,18,hl=0.95,hu=1.045)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.