| strapPnL | R Documentation |
This is a volatility strategy consisting of a long position in two ATM (at the money) calls , and a long position in an ATM (at the money) put option with a strike price X. This is a net debit trade. The trader or investor has bullish outlook (Kakushadze & Serur, 2018) .
strapPnL( ST, X, C1, C2, P, hl = 0, hu = 2, spot = spot, pl = pl, myData = myData, myTibble = myTibble, PnL = PnL )
ST |
Spot Price at time T. |
X |
Strike Price or eXercise price. |
C1 |
Call Premium or Call Price paid for first bought Call. |
C2 |
Call Premium or Call Price paid for bought Call. |
P |
Put Premium paid for the bought put. |
hl |
lower bound value for setting lower-limit of x-axis displaying spot price. |
hu |
upper bound value for setting upper-limit of x-axis displaying spot price. |
spot |
Spot Price |
pl |
Profit and Loss |
myData |
Data frame |
myTibble |
tibble |
PnL |
Profit and Loss |
According to conceptual details given by Cohen (2015), and a closed form solution provided by Kakushadze and Serur (2018), this method is developed, and the given examples are created, to compute per share Profit and Loss at expiration for Strap Option Strategy and draw its graph in the Plots tab.
graph of the strategy
strapPnL(25,25,2.40,2.40,1.70) strapPnL(40,40,3,3,2,hl=0.7,hu=1.2) strapPnL(1000,1010,18,18,10,hl=0.955,hu=1.055)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.